==> Alpha-0.7.5-src.tar.bz2: Alpha-0.7.5-src/Alpha/StdAfx.h <==
// stdafx.h : W̃VXe CN[h t@CA
//            ܂͎QƉ񐔂A܂ύXȂ
//            vWFNgp̃CN[h t@CLq܂B
//

#if !defined(AFX_STDAFX_H__A9DB83DB_A9FD_11D0_BFD1_444553540000__INCLUDED_)
#define AFX_STDAFX_H__A9DB83DB_A9FD_11D0_BFD1_444553540000__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#define WIN32_LEAN_AND_MEAN		// Windows wb_[wǎgpȂX^btO܂

#define STRICT
#define UNICODE
#define _UNICODE
#define WINVER			0x0501
#define _WIN32_WINDOWS  0x0401
#define _WIN32_WINNT	0x0501

#include <windows.h>
#include <process.h>
#include <shellapi.h>
#include <shlwapi.h>
#include <shlobj.h>
#include <commdlg.h>
#include <commctrl.h>

#undef max	// ȂCl[
#undef min
#if(_MSC_VER < 1300)
namespace std {
	template<typename T>
	inline const T& max(const T& a1, const T& a2) {
		return (a1 < a2) ? a2 : a1;
	}
	template<typename T, typename Pr>
	inline const T& max(const T& a1, const T& a2, Pr pred) {
		return pred(a1, a2) ? a2 : a1;
	}
	template<typename T>
	inline const T& min(const T& a1, const T& a2) {
		return (a2 < a1) ? a2 : a1;
	}
	template<typename T, typename Pr>
	inline const T& min(const T& a1, const T& a2, Pr pred) {
		return pred(a2, a1) ? a2 : a1;
	}
}
#endif

#pragma warning(disable: 4290)	// uC++ ̗O̎w͖܂v(3)
#pragma warning(disable: 4503)	// uꂽO̒Ez܂v(1)
#pragma warning(disable: 4786)	// uʎq 'number' ɐ؂l߂܂v(3)
#include <cassert>		// assert
#include <stdexcept>	// eONX
#include <string>		// wstring, string
#include <sstream>		// wostringstream Ȃ
using namespace std;


#define __WTIMESTAMP__		_T(__TIMESTAMP__)
#define IDS_APPNAME			L"Alpha"
#define IDS_APPVERSION		L"0.7.5\x03B1"
#ifdef _DEBUG
#define IDS_APPVERSIONINFO	L"debug version [" __WTIMESTAMP__ L"]"
#else
#define IDS_APPVERSIONINFO	L"[" __WTIMESTAMP__ L"]"
#endif
#define IDS_APPFULLVERSION	IDS_APPNAME L" " IDS_APPVERSION L" " IDS_APPVERSIONINFO

#ifdef _DEBUG
#define ALERT(msg)	::MessageBoxW(0, (msg), L"Debug alert", MB_ICONEXCLAMATION);
#else
#define ALERT(msg)
#endif

// for XR[v (VC7 ł /Zc:forScope g)
#if(_MSC_VER < 1300)
#define for if(0); else for 
#endif

namespace {

/// ̐ΒlԂ֐
template<typename T>
T dif(T i0, T i1) {
	return (i0 > i1) ? i0 - i1 : i1 - i0;
}

}


// TODO: vOŕKvȃwb_[QƂǉĂB

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_STDAFX_H__A9DB83DB_A9FD_11D0_BFD1_444553540000__INCLUDED_)

==> Alpha-0.7.5.4-src.tar.bz2: Alpha-0.7.5.4-src/Alpha/StdAfx.h <==
// stdafx.h : W̃VXe CN[h t@CA
//            ܂͎QƉ񐔂A܂ύXȂ
//            vWFNgp̃CN[h t@CLq܂B
//

#if !defined(AFX_STDAFX_H__A9DB83DB_A9FD_11D0_BFD1_444553540000__INCLUDED_)
#define AFX_STDAFX_H__A9DB83DB_A9FD_11D0_BFD1_444553540000__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#define WIN32_LEAN_AND_MEAN		// Windows wb_[wǎgpȂX^btO܂

#define STRICT
#define UNICODE
#define _UNICODE
#define WINVER			0x0501
#define _WIN32_WINDOWS  0x0401
#define _WIN32_WINNT	0x0501
#define NOMINMAX

#include <windows.h>
#include <process.h>
#include <shellapi.h>
#include <shlwapi.h>
#include <shlobj.h>
#include <commdlg.h>
#include <commctrl.h>

#if(_MSC_VER < 1300)
namespace std {
	template<typename T>
	inline const T& max(const T& a1, const T& a2) {
		return (a1 < a2) ? a2 : a1;
	}
	template<typename T, typename Pr>
	inline const T& max(const T& a1, const T& a2, Pr pred) {
		return pred(a1, a2) ? a2 : a1;
	}
	template<typename T>
	inline const T& min(const T& a1, const T& a2) {
		return (a2 < a1) ? a2 : a1;
	}
	template<typename T, typename Pr>
	inline const T& min(const T& a1, const T& a2, Pr pred) {
		return pred(a2, a1) ? a2 : a1;
	}
	typedef unsigned int	size_t;
}
#endif

#pragma warning(disable: 4290)	// uC++ ̗O̎w͖܂v(3)
#pragma warning(disable: 4503)	// uꂽO̒Ez܂v(1)
#pragma warning(disable: 4786)	// uʎq 'number' ɐ؂l߂܂v(3)
#include <cassert>		// assert
#include <stdexcept>	// eONX
#include <string>		// wstring, string
#include <sstream>		// wostringstream Ȃ
using namespace std;


#define __WTIMESTAMP__		_T(__TIMESTAMP__)
#define IDS_APPNAME			L"Alpha"
#define IDS_APPVERSION		L"0.7.5.4\x03B1"
#ifdef _DEBUG
#define IDS_APPVERSIONINFO	L"debug version [" __WTIMESTAMP__ L"]"
#else
#define IDS_APPVERSIONINFO	L"[" __WTIMESTAMP__ L"]"
#endif
#define IDS_APPFULLVERSION	IDS_APPNAME L" " IDS_APPVERSION L" " IDS_APPVERSIONINFO

#ifdef _DEBUG
#define ALERT(msg)	::MessageBoxW(0, (msg), L"Debug alert", MB_ICONEXCLAMATION);
#else
#define ALERT(msg)
#endif

// for XR[v (VC7 ł /Zc:forScope g)
#if(_MSC_VER < 1300)
#define for if(0); else for 
#endif


// TODO: vOŕKvȃwb_[QƂǉĂB

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_STDAFX_H__A9DB83DB_A9FD_11D0_BFD1_444553540000__INCLUDED_)
